from setuptools import setup, find_packages

setup(

name = 'bobblob',
version = '1.0.6',
author = 'kanderusss',
requires = [],
py_modules=['bobblob'],
packages=find_packages(),
description='Bob - the blob',
long_description=r'''This is Bob - the blob.
Bob can talk.
I love Bob!

              /-------------\
              | Hi! Im Bob! |
            - \-------------/
/~~~~~~~~~\
|   O O   |
|    ~    |
\~~~~~~~~~/''',
 long_description_content_type='text/markdown'
)



"""This is Bob - The blob.
Bob can talk!
I love Bob!"""

bobsayTemplate = r'''
       /-{line}-\
       | {text} |
     - \-{line}-/
/~~~~~~~~~\
|   O O   |
|    ~    |
\~~~~~~~~~/
'''


def bobsay(text: str = 'Hi! Im Bob!'):
	r"""Bob talks."""
	if text:
		line = "-" * len(text)
		print(bobsayTemplate.format(line=line, text=text))
